# CONTAINS TECHNICAL DATA/COMPUTER SOFTWARE DELIVERED TO THE U.S. GOVERNMENT WITH UNLIMITED RIGHTS
#
# Contract No.: CA 80MSFC17M0022
# Contractor Name: Universities Space Research Association
# Contractor Address: 7178 Columbia Gateway Drive, Columbia, MD 21046
#
# Copyright 2017-2022 by Universities Space Research Association (USRA). All rights reserved.
#
# Developed by: William Cleveland and Adam Goldstein
#               Universities Space Research Association
#               Science and Technology Institute
#               https://sti.usra.edu
#
# Developed by: Daniel Kocevski
#               National Aeronautics and Space Administration (NASA)
#               Marshall Space Flight Center
#               Astrophysics Branch (ST-12)
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
# in compliance with the License. You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software distributed under the License
# is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied. See the License for the specific language governing permissions and limitations under the
# License.
#
import os
from pathlib import Path
import shutil

from importlib.resources import files

_gdt_data = files('gdt.data')

__version__ = '2.2.0'

suite_path = Path(__file__).parent.parent

if 'GDT_BASE' in os.environ:
    base_path = Path(os.environ['GDT_BASE'])
else:
    base_path = Path.home().joinpath('.gammaray_data_tools', __version__)

cache_path = base_path.joinpath('cache')

if 'GDT_DATA' in os.environ:
    data_path = Path(os.environ['GDT_DATA'])
else:
    data_path = base_path.joinpath('test_data')

# Create the data directory and copy a sample spectral data file for tutorial
data_path.mkdir(parents=True, exist_ok=True)
_src = _gdt_data / 'specfit.npz'
_dest = data_path / 'specfit.npz'

if not _dest.exists():
    shutil.copyfile(_src, _dest)
